import React from 'react';
import { Container, Typography } from "@material-ui/core";
import { MuiThemeProvider as ThemeProvider, StylesProvider } from "@material-ui/core/styles";
import { studentTheme } from "./ui/theme";
import { InternshipForm } from "@/forms/Internship";
import { MuiPickersUtilsProvider } from "@material-ui/pickers";
import MomentUtils from "@date-io/moment";
import { BrowserRouter, Switch, Route } from "react-router-dom"

import "moment/locale/pl"
moment.locale("pl")

import '@/styles/overrides.scss'
import moment, { Moment } from "moment";
import { routes } from "@/routing";

class LocalizedMomentUtils extends MomentUtils {
    getDatePickerHeaderText(date: Moment): string {
        return this.format(date, "d MMM yyyy");
    }
}

function App() {
  return (
      <StylesProvider injectFirst>
          <MuiPickersUtilsProvider utils={ LocalizedMomentUtils } libInstance={ moment }>
              <ThemeProvider theme={ studentTheme }>
                  <BrowserRouter>
                      <div className="app">
                          <Switch>{ routes.map(({ name, content, ...route }) => <Route { ...route } key={ name }>{ content() }</Route>) }</Switch>
                      </div>
                  </BrowserRouter>
              </ThemeProvider>
          </MuiPickersUtilsProvider>
      </StylesProvider>
  );
}

export default App;
